import { Module } from "@nestjs/common";
import { JwtModule } from "@nestjs/jwt";
import { SequelizeModule } from "@nestjs/sequelize";
import { ShopService } from "./shop.service";
import { ShopController } from "./shop.controller";
import { RoleGuard } from "src/users/guard/role.guard";
import { JwtAuthGuard } from "src/users/guard/auth.guard";
import { Product } from "./entities/product.entity";
import { Cart } from "./entities/cart.entity";
import { Wallet } from "./entities/wallet.entity";
import { Transaction } from "./entities/transaction.entity";
import { Payment } from "./entities/payment.entity";
import { Invoice } from "./entities/invoice.entity";
import { RedisService } from "src/redis/redis.service";
import { JwtStrategy } from "src/users/guard/jwt.strategy";

@Module({
  imports: [
    SequelizeModule.forFeature([Product, Cart, Invoice, Wallet, Transaction, Payment]),
    JwtModule.register({
      secret: process.env.JWT_SECRET,
      signOptions: { expiresIn: "1h" },
    }),
  ],
  controllers: [ShopController],
  providers: [ShopService, RoleGuard, JwtAuthGuard,RedisService,JwtStrategy],
})
export class ShopModule {}
